@@ -18,8 +18,8 @@ __author__ = 'Orsiris de Jong'
 __copyright__ = 'Copyright (C) 2020-2021 Orsiris de Jong'
 __description__ = 'Simple virtualization platform identification for Windows guest'
 __licence__ = 'BSD 3 Clause'
-__version__ = '0.3.1'
-__build__ = '2021022201'
+__version__ = '0.3.2'
+__build__ = '2021070201'
 
 
 from typing import Tuple
@@ -28,7 +28,7 @@ import re
 import windows_tools.wmi_queries
 
 
-logger = getLogger()
+logger = getLogger(__intname__)
 
 
 def get_relevant_platform_info() -> dict:
@@ -38,25 +38,29 @@ def get_relevant_platform_info() -> dict:
     try:
         # Create a list of various computer data which will allow to check if we're running on a virtual system
 
-        result = windows_tools.wmi_queries.query_wmi('SELECT Manufacturer, Model FROM Win32_ComputerSystem')
+        result = windows_tools.wmi_queries.query_wmi('SELECT Manufacturer, Model FROM Win32_ComputerSystem',
+                                                     name='windows_tools.virtualization.get_relavant_platform_info_1')
         try:
             product_id['computersystem'] = result[0]
         except IndexError:
             pass
 
-        result = windows_tools.wmi_queries.query_wmi('SELECT Manufacturer, Product FROM Win32_Baseboard')
+        result = windows_tools.wmi_queries.query_wmi('SELECT Manufacturer, Product FROM Win32_Baseboard',
+                                                     name='windows_tools.virtualization.get_relavant_platform_info_2')
         try:
             product_id['baseboard'] = result[0]
         except IndexError:
             pass
 
-        result = windows_tools.wmi_queries.query_wmi('SELECT Manufacturer, SerialNumber, Version FROM Win32_Bios')
+        result = windows_tools.wmi_queries.query_wmi('SELECT Manufacturer, SerialNumber, Version FROM Win32_Bios',
+                                                     name='windows_tools.virtualization.get_relavant_platform_info_3')
         try:
             product_id['bios'] = result[0]
         except IndexError:
             pass
 
-        result = windows_tools.wmi_queries.query_wmi('SELECT Caption, Model, SerialNumber FROM Win32_DiskDrive')
+        result = windows_tools.wmi_queries.query_wmi('SELECT Caption, Model, SerialNumber FROM Win32_DiskDrive',
+                                                     name='windows_tools.virtualization.get_relavant_platform_info_4')
         try:
             product_id['diskdrive'] = result[0]
         except IndexError:
